## The Code
**Pople** is a toolkit written in Python to perform _ab initio_ thermochemistry calculations. The present version [Pople v1.0](https://github.com/moldis-group/Pople) supports G4(MP2) calculations using the [ORCA quantum chemistry program package](https://www.faccts.de/orca/) for all the electronic structure calculations. Pople enables customizing every step in a G4(MP2) calculation, facilitating the user to explore effects of level of theories and basis sets on the speed and accuracy. G4(MP2)-XP is a variant based on DLPNO-CCSD(T),RI-MP2, RI-DFT and RI-HF approximations permitting thermochemistry calculations of molecules as large as buckminsterfullerene. 

* * *

## Calculations supported
1. Enthalpy of formation
2. Atomization energy 
3. Ionization Potential (vertical and adiabatic)
4. Electron Affinity (vertical and adiabatic)
5. Proton Affinity
6. Intermolecular Binding Energy

For installation, manual, and tutorials at https://moldis-group.github.io/pople/


